@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: yesod
 version: 1.4.2
-id: yesod-1.4.2-19c818c92a78173ca972a4756b867451
-key: yesod_7oIrVONOtHQBLbvIs6ISqu
+id: yesod-1.4.2-c7ab180e681ee6773fbc9cbace33c04c
+key: yesod_H5GlsVOADT03djUfKO6kHn
 license: MIT
 maintainer: Michael Snoyman <michael@snoyman.com>
 stability: Stable
@@ -21,9 +21,9 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-1.4.2
 library-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-1.4.2
 data-dir: /usr/share/arm-linux-ghc-7.10.3/yesod-1.4.2
-hs-libraries: HSyesod-1.4.2-7oIrVONOtHQBLbvIs6ISqu
+hs-libraries: HSyesod-1.4.2-H5GlsVOADT03djUfKO6kHn
 depends:
-    aeson-0.11.1.3-f91e7713a2275d7d7640efb25da00228
+    aeson-0.11.1.4-4ad27f2347131dcc86b1af72cd00fe7c
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     blaze-html-0.8.1.1-1d54daeba5477a1aa0462b832a558865
     blaze-markup-0.7.0.3-fed4a147945def017f9ea9594b30666a
@@ -36,7 +36,7 @@ depends:
     monad-logger-0.3.18-0974645d267a817a7b3484945a31ce66
     safe-0.3.9-b613242f536083d5bb04920ede356aea
     semigroups-0.18.1-30b269dfd15f1b13a72c07aebe8ef1de
-    shakespeare-2.0.7-b02812f82b28748b41c9d5376d30ec4d
+    shakespeare-2.0.7-0211859c61478c312aeaa5f154b501d3
     streaming-commons-0.1.15.2-e8e35f9b3c5e3a1a9d565bf7c4ec1900
     template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
     text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
@@ -44,14 +44,14 @@ depends:
     unix-2.7.1.0-a583968f8d5891c6bf334fddb26b19a6
     unordered-containers-0.2.7.0-d91279dcd5fa13d7f88095dc08e2fda6
     wai-3.2.0-7ea0a12f4ecd69f2ebdeef193a494430
-    wai-extra-3.0.15-892ae0d90f4ac449b234107e8e19950e
+    wai-extra-3.0.15-954ac840c460f6e3c2fb191ca01c5fce
     wai-logger-2.2.4.1-9478a6051df96b8d5b3214f7fcca2185
-    warp-3.2.3-dcf3c2d07cb749512799bfc02b96e049
-    yaml-0.8.16-04f42cfb9aefb15b48ee9e9830b4bdd5
-    yesod-auth-1.4.12-47ed49dd2f1dd6833efdba84d8936393
-    yesod-core-1.4.19-cd3cf9fa719923698d632da2425a0be2
-    yesod-form-1.4.6-bb031e57576d96500c31da9205b30267
-    yesod-persistent-1.4.0.3-babf98306f0fd9c7fb84dae44ac8bfd9
+    warp-3.2.3-6de819de378ae4c57281b63b66004254
+    yaml-0.8.16-50dd72d7df25e45cd672d7359cb18648
+    yesod-auth-1.4.12-45cd7bbc9c204488900d549568a3d042
+    yesod-core-1.4.19-83d7786ccf417e9f8ff12c2ba1e4758e
+    yesod-form-1.4.6-74e09ec1e0cc3b893c314cc7937841de
+    yesod-persistent-1.4.0.3-2e82e69e0978c8663ea0bc70a29c9f56
 haddock-interfaces: /usr/share/doc/haskell-yesod/html/yesod.haddock
 haddock-html: /usr/share/doc/haskell-yesod/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
